@@ -12,10 +12,11 @@ use Plack::Util ();
 use Carp ();
 
 my $xslate = Text::Xslate->new(
-    syntax => 'Kolon',
+    syntax => 'TTerse',
     type   => 'text',
     tag_start => '<%',
     tag_end   => '%>',
+    'module'   => [ 'Text::Xslate::Bridge::TT2Like' ],
 );
 
 sub infof {
